all_generated_locations_for

Function all_generated_locations_for 

#[unsafe(no_mangle)]
pub extern "C" fn all_generated_locations_for( mappings: *mut Mappings<()>, source: u32, original_line: u32, has_original_column: bool, original_column: u32, )
Find all mappings for the given original location, and invoke the mapping_callback on each of them.

If has_original_column is true, then the mapping_callback is only invoked with mappings with matching source and original line and original column is equal to original_column. If has_original_column is false, then the original_column argument is ignored, and the mapping_callback is invoked on all mappings with matching source and original line.